@@ -25,6 +25,15 @@ DESC
     [ INVALID, 'junkline' => 'ASCII junk line w/o colon'],
     [ INVALID, 'cr' => 'line just containing CR: \r\r\n'],
 
+    [ 'various broken responses' ],
+    [ INVALID, 'code-only' => 'status line stops after code, no phrase'],
+    [ INVALID, 'http-lower' => 'http/1.1 instead of HTTP/1.1'],
+    [ INVALID, 'proto:HTTP/0.9' => 'HTTP/0.9 instead of HTTP/1.1'],
+    [ INVALID, 'proto:HTTP/1.2' => 'HTTP/1.2 instead of HTTP/1.1'],
+    [ INVALID, 'proto:FTP/1.1' => 'FTP/1.1 instead of HTTP/1.1'],
+    [ INVALID, 'cr-no-lf' => 'use \r instead of \r\n' ],
+    [ INVALID, 'no-cr-lf' => 'use \n instead of \r\n' ],
+
     [ 'redirect without location' ],
     [ INVALID, '301' => 'code 301 without location header'],
     [ INVALID, '302' => 'code 301 without location header'],
@@ -40,6 +49,10 @@ DESC
     [ INVALID, '204' => 'code 204 with body'],
     [ INVALID, '304' => 'code 304 with body'],
     [ INVALID, '305' => 'code 305 with body'],
+    [ INVALID, '2xx' => 'invalid status code with non-digits (2xx)'],
+    [ INVALID, '2'   => 'invalid status code, only single digit (2)'],
+    [ INVALID, '2000' => 'invalid status code, too much digits (2000)'],
+    [ INVALID, '0200' => 'invalid status code, numeric (0200)'],
 );
 
 sub make_response {
@@ -50,6 +63,8 @@ sub make_response {
     my $te = 'clen';
     my $only = 0;
     my $code = 200;
+    my $statusline;
+    my @transform;
     for (split(';',$spec)) {
 	if ( $_ eq 'emptycont' ) {
 	    $hdr .= "Foo: bar\r\n \r\n"
@@ -75,9 +90,19 @@ sub make_response {
 	    $only = 1;
 	} elsif ( $_ eq 'http09' ) {
 	    return $data;
-	} elsif ( m{^(\d+)$} ) {
+	} elsif ( m{^(\d.*)$} ) {
 	    $code = $1;
 	    $hdr .= "Connection: close\r\n";
+	} elsif ( $_ eq 'code-only' ) {
+	    $statusline = "HTTP/$version $code\r\n";
+	} elsif ( $_ eq 'http-lower' ) {
+	    $statusline = "http/$version $code\r\n";
+	} elsif ( $_ eq 'cr-no-lf' ) {
+	    push @transform, sub { $_[0] =~ s{\r?\n}{\r}g }
+	} elsif ( $_ eq 'no-cr-lf' ) {
+	    push @transform, sub { $_[0] =~ s{\r?\n}{\n}g }
+	} elsif ( m{^proto:(.*)} ) {
+	    $statusline = "$1 $code ok\r\n";
 	} else {
 	    die $_
 	}
@@ -86,7 +111,12 @@ sub make_response {
 	$hdr .= "Yet-another-header: foo\r\n";
 	$hdr .= "Content-length :".length($data)."\r\n" if $hdr eq 'clen';
     }
-    return "HTTP/$version $code ok\r\n$hdr\r\n$data";
+    $statusline ||= "HTTP/$version $code ok\r\n";
+    $hdr = "$statusline$hdr\r\n";
+    for(@transform) {
+	$_->($hdr,$data);
+    }
+    return $hdr . $data;
 }
 
 1;
